package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.SysAdvancedConfig;
import com.huiju.estateagents.service.ISysAdvancedConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

/**
 * <p>
    * 高级配置基础表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2020-02-26
 */
@RestController
@RequestMapping("/")
public class SysAdvancedConfigController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(SysAdvancedConfigController.class);

    @Autowired
    public ISysAdvancedConfigService iSysAdvancedConfigService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/sysAdvancedConfig",method= RequestMethod.GET)
    public ResponseBean sysAdvancedConfigList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                              @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<SysAdvancedConfig> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<SysAdvancedConfig> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<SysAdvancedConfig> result = iSysAdvancedConfigService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysAdvancedConfigList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param sysAdvancedConfig 实体对象
     * @return
     */
    @RequestMapping(value="/sysAdvancedConfig",method= RequestMethod.POST)
    public ResponseBean sysAdvancedConfigAdd(@RequestBody SysAdvancedConfig sysAdvancedConfig){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysAdvancedConfigService.save(sysAdvancedConfig)){
                responseBean.addSuccess(sysAdvancedConfig);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysAdvancedConfigAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/sysAdvancedConfig/{id}", method= RequestMethod.DELETE)
    public ResponseBean sysAdvancedConfigDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iSysAdvancedConfigService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysAdvancedConfigDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param sysAdvancedConfig 实体对象
     * @return
     */
    @RequestMapping(value="/sysAdvancedConfig/{id}",method= RequestMethod.PUT)
    public ResponseBean sysAdvancedConfigUpdate(@PathVariable Integer id,
                                        @RequestBody SysAdvancedConfig sysAdvancedConfig){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iSysAdvancedConfigService.updateById(sysAdvancedConfig)){
                responseBean.addSuccess(sysAdvancedConfig);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysAdvancedConfigUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/sysAdvancedConfig/{id}",method= RequestMethod.GET)
    public ResponseBean sysAdvancedConfigGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iSysAdvancedConfigService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("sysAdvancedConfigDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
